/**************************************************************************

    channel3d.h  - KMidChannel3D widget, a Channel widget with 3D look
    Copyright (C) 1998  Antonio Larrosa Jimenez

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

    Send comments and bug fixes to larrosa@kde.org
    or to Antonio Larrosa, Rio Arnoya, 10 5B, 29006 Malaga, Spain

***************************************************************************/

#ifndef KMIDCHANNEL3D_H
#define KMIDCHANNEL3D_H

#include "channel.h"

class KMidChannel3D : public KMidChannel
{
public:
    KMidChannel3D(int chn,TQWidget *parent);


    virtual void drawDo   (TQPainter *qpaint,int x,int p);
    virtual void drawDo__ (TQPainter *qpaint,int x,int p);
    virtual void drawRe   (TQPainter *qpaint,int x,int p);
    virtual void drawRe__ (TQPainter *qpaint,int x,int p);
    virtual void drawMi   (TQPainter *qpaint,int x,int p);
    virtual void drawFa   (TQPainter *qpaint,int x,int p);
    virtual void drawFa__ (TQPainter *qpaint,int x,int p);
    virtual void drawSol  (TQPainter *qpaint,int x,int p);
    virtual void drawSol__(TQPainter *qpaint,int x,int p);
    virtual void drawLa   (TQPainter *qpaint,int x,int p);
    virtual void drawLa__ (TQPainter *qpaint,int x,int p);
    virtual void drawSi   (TQPainter *qpaint,int x,int p);
    
    
};

#endif
